pub enum Constraint {
Length(usize),
Percent(usize),
Min(usize),
Max(usize),
MinMax(usize, usize),
Fill(usize),
}Expand description
Size constraints Size constraints
Variants
Length(usize)
Actual size
Percent(usize)
Percentage size of the parent widget
Min(usize)
Minimum size of the widget, widget expands to fit content
Max(usize)
Maximum size of the widget, widget expands to fit content
MinMax(usize, usize)
Minimum and maximum size of the widget, widget expands to fit content
Fill(usize)
Fills rest of the space (space is divided by all widgets with fill)