Vec2

Struct Vec2 

pub struct Vec2<T = usize> {
    pub x: T,
    pub y: T,
}
A 2D vector implementing basic operations A 2D vector implementing basic operations

Fields

x: Ty: T

Implementations

Source

impl<T> Vec2<T>

pub fn new(x: T, y: T) -> Self

Creates new Vec2 containing given x and y coordinates

Source

impl Vec2<usize>

pub fn saturating_sub<T>(&self, rhs: T) -> Self
where T: Into<Self>,

Saturating Vec2 subtraction. Computes self - rhs, saturating at the numeric bounds instead of overlowing

pub fn checked_sub<T>(&self, rhs: T) -> Option<Self>
where T: Into<Self>,

Checked Vec2 subtraction. Computes self - rhs, returning None if overflow occured.

Source

impl<T> Vec2<T>
where T: Copy + Into<f64>,

pub fn magnitude(&self) -> f64

Calculates magnituted of the 2D vector

pub fn normalize(&self) -> Vec2<f64>

Converts 2D vector to its normalized form (length equal to 1)

Source

impl<T> Vec2<T>
where T: Copy,

pub fn transpone(&mut self)

Transpones Vec2

pub fn inverse(&self) -> Self

Transpones Vec2 and returns new Vec2

Source

impl<T> Vec2<T>
where T: Copy + PartialOrd,

pub fn to(self, other: Vec2<T>) -> Vec2Range<T>

Creates new 2D vector range with first value inclusive and second exclusive