Element

Struct Element 

pub struct Element {
    pub type_id: TypeId,
    pub widget: Box<dyn Widget>,
}
A container for any widget implementing the Widget trait. A container for any widget implementing the Widget trait.

This is the primary type used to store and manipulate widgets in layout trees. Element wraps a widget in a dynamic trait object.

Use Element::new to convert a widget into an Element.

Fields

type_id: TypeIdwidget: Box<dyn Widget>

Implementations

Source

impl Element

pub fn new<W>(widget: W) -> Self
where W: Widget + 'static,

Creates a new Element from a given widget.

This is commonly used to wrap widgets when composing layouts.

Example
let span = Span::new("Hello");
let element = Element::new(span);
pub fn map<W: Widget + 'static, F: FnOnce(W) -> W>(self, f: F) -> Self

pub fn downcast_ref<W: Widget>(&self) -> Option<&W>

Downcasts widget stored in the Element to given type, returns optional reference to the downcast widget on success.

pub fn downcast_mut<W: Widget>(&mut self) -> Option<&mut W>

Downcasts widget stored in the Element to given type, returns optional mutable reference to the downcast widget on success.