Grid

Struct Grid 

pub struct Grid { /* private fields */ }
A layout widget that arranges children in a grid specified by rows and columns. A layout widget that arranges children in a grid specified by rows and columns.

Each row and column is defined by a Unit, which you can read more about in its documentation.

Children can be placed by specifying their zero-based column and row indices.

Example

let mut grid = Grid::new(
    vec![Unit::Length(3), Unit::Length(5), Unit::Fill(1)],
    vec![Unit::Fill(1), Unit::Length(1), Unit::Fill(1)],
);
grid.push("Grid", 1, 1);

let mut term = Term::default();
term.render(grid)?;

Implementations

Source

impl Grid

pub fn new<T1, T2>(cols: T1, rows: T2) -> Self
where T1: IntoIterator, T1::Item: Into<Unit>, T2: IntoIterator, T2::Item: Into<Unit>,

Creates a new Grid from columns and rows specifications.

Both cols and rows accept any iterable of types convertible into Unit.

Example
let mut grid = Grid::new([3, 5, 3], [3, 1, 1]);
pub fn empty() -> Self

Creates an new empty Grid with no rows or columns.

pub fn row(&mut self, row: Unit)

Adds a new row definition to the Grid.

pub fn col(&mut self, col: Unit)

Adds given column to current columns

pub fn add_child<T>(&mut self, child: T, col: usize, row: usize)
where T: Into<Element>,

👎Deprecated since 0.6.0: Kept for compatibility purposes; use push function instead

Adds child to the grid to given row and column

pub fn push<T>(&mut self, child: T, col: usize, row: usize)
where T: Into<Element>,

Adds a child widget at the specified column and row.

Parameters
  • child: The widget to add (any type convertible to Element)
  • col: Zero-based column index (x)
  • row: Zero-based row index (y)