Row

Struct Row 

pub struct Row { /* private fields */ }
Represents a single row in a [Table] widget.

A Row consists of a list of Elements (one per column) and base style of the row.

Example

let row = Row::new(["First", "Second", "Third"]).style(Color::Red);
let row: Row = ["First", "Second", "Third"].into_iter().collect();

Implementations

Source

impl Row

pub fn new<T>(cells: T) -> Self
where T: IntoIterator, T::Item: Into<Element>,

Creates a new Row from the given cells.

You can provide any type that can be converted into an iterator of any type, that can be converted into Element.

Example
let row = Row::new(["First", "Second", "Third"]);
let row = Row::new(vec![
    "First".fg(Color::Red),
    "Second".fg(Color::Green),
    "Third".fg(Color::Blue),
]);
pub fn style<S>(self, style: S) -> Self
where S: Into<Style>,

Sets the base style of the Row