Table

Struct Table 

pub struct Table { /* private fields */ }
A widget that displays a table with configurable column idths, optional header and scrollable row content. A widget that displays a table with configurable column widths, optional header and scrollable row content.

Each cell is represented by an Element, so cell can be any widget. Layout of the cells is controlled by per-column widths and optional spacing between columns.

Example

let rows = get_people();
let widths = [Unit::Fill(3), Unit::Fill(1), Unit::Fill(3)];
let state = Rc::new(RefCell::new(TableState::new(0).selected(1)));

let table = Table::new(rows, widths, state)
    .header(vec!["Name", "Age", "Email"])
    .header_separator(BorderType::Double)
    .column_spacing(2);

let mut term = Term::default();
term.render(table)?;

Implementations

Source

impl Table

pub fn new<R, W>(rows: R, widths: W, state: Rc<RefCell<TableState>>) -> Self
where R: IntoIterator, R::Item: Into<Row>, W: IntoIterator, W::Item: Into<Unit>,

Creates new Table with given rows and columns widths

pub fn header<H>(self, header: H) -> Self
where H: Into<Row>,

Adds given header to the Table

pub fn header_separator(self, separator: BorderType) -> Self

Sets the header separator of the Table

pub fn rows<R, C>(self, rows: R) -> Self
where R: IntoIterator, R::Item: IntoIterator<Item = C>, C: Into<Element>,

Sets Table rows to the given value

pub fn selected_row_style<S>(self, style: S) -> Self
where S: Into<Style>,

Sets the selected row style

pub fn selected_column_style<S>(self, style: S) -> Self
where S: Into<Style>,

Sets the selected column style

pub fn selected_cell_style<S>(self, style: S) -> Self
where S: Into<Style>,

Sets the selected cell style

pub fn widths<W>(self, widths: W) -> Self
where W: IntoIterator, W::Item: Into<Unit>,

Sets columns widths of the Table

pub fn column_spacing(self, space: usize) -> Self

Sets the column spacing of the Table

pub fn auto_scroll(self) -> Self

Enables automatic scrolling to ensure the selected item is visible.

pub fn force_scrollbar(self) -> Self

Forces scrollbar to be always visible. By default the scrollbar hides when the content doesn’t overflow.