TableState

Struct TableState 

pub struct TableState {
    pub offset: usize,
    pub selected: Option<usize>,
    pub selected_column: Option<usize>,
}
State of the Table widget, including scroll offset, selected index and selected column. State of the Table widget, including scroll offset, selected index and selected column.

Fields

offset: usizeselected: Option<usize>selected_column: Option<usize>

Implementations

Source

impl TableState

pub fn new(offset: usize) -> Self

Creates a new TableState with the given scroll offset, no selected item and no selected column.

pub fn selected<T>(self, selected: T) -> Self
where T: Into<Option<usize>>,

Sets the selected index to the given value

pub fn selected_column<T>(self, selected: T) -> Self
where T: Into<Option<usize>>,

Sets the selected column to the given value