Widget

Trait Widget 

pub trait Widget: Any {
    // Required methods
    fn render(&self, buffer: &mut Buffer, rect: Rect, cache: &mut Cache);
    fn height(&self, size: &Vec2) -> usize;
    fn width(&self, size: &Vec2) -> usize;

    // Provided method
    fn children(&self) -> Vec<&Element> { ... }
}
Trait implemented by all the widgets. Trait implemented by all the widgets.

A widget is a visual component that can render itself to a Buffer and report its size requirements for layout purposes.

Use Element to store and manipulate widgets in a uniform way.

Users will use Widget trait directly only when implementing custom widget, otherwise they will use built-in widgets like [Span], [List] and so on.

Required Methods

fn render(&self, buffer: &mut Buffer, rect: Rect, cache: &mut Cache)

Renders the widget into the given Buffer within the provided Rect bounds.

fn height(&self, size: &Vec2) -> usize

Returns the height of the Widget based on the width of the given size.

fn width(&self, size: &Vec2) -> usize

Returns the width of the Widget based on the height of the given size.

Provided Methods

fn children(&self) -> Vec<&Element>

Gets widget’s children

Implementations

Source

impl dyn Widget

pub fn as_any(&self) -> &dyn Any

pub fn as_any_mut(&mut self) -> &mut dyn Any