pub struct Element {
pub type_id: TypeId,
pub widget: Box<dyn Widget>,
}Expand description
A container for any widget implementing the Widget trait.
A container for any widget implementing the Widget trait.
This is the primary type used to store and manipulate widgets in layout
trees. Element wraps a widget in a dynamic trait object.
Use Element::new to convert a widget into an Element.
Fields
type_id: TypeIdwidget: Box<dyn Widget>Implementations
Sourceimpl Element
impl Element
pub fn map<W: Widget + 'static, F: FnOnce(W) -> W>(self, f: F) -> Self