pub struct Grid { /* private fields */ }Expand description
A layout widget that arranges children in a grid specified by rows and columns. A layout widget that arranges children in a grid specified by rows and columns.
Each row and column is defined by a Unit, which you can read more about
in its documentation.
Children can be placed by specifying their zero-based column and row indices.
Example
let mut grid = Grid::new(
vec![Unit::Length(3), Unit::Length(5), Unit::Fill(1)],
vec![Unit::Fill(1), Unit::Length(1), Unit::Fill(1)],
);
grid.push("Grid", 1, 1);
let mut term = Term::default();
term.render(grid)?;Implementations