pub struct Paragraph { /* private fields */ }Expand description
A widget combining multiple widgets implementing the Text trait into
single widget.
A Paragraph combines multiple widgets implementing the Text trait
into single widget, displaying them sequantially with configurable
separator.
Unlike layout-based widgets, Paragraph places spans directly next to
each other, allowing for more natural inline text composition.
Example
// Creates a Paragraph from a list of spans
let items: Vec<Box<dyn Text>> = vec![
Box::new("This is a text in".fg(Color::Yellow)),
Box::new("paragraph".modifier(Modifier::BOLD).fg(Color::Cyan)),
Box::new("and it adds".to_span()),
Box::new("separator".modifier(Modifier::ITALIC)),
];
let mut p = Paragraph::new(items)
.wrap(Wrap::Letter)
.separator("-");
// Alternatively, use the `paragraph!` macro for convenience
let mut p = paragraph!(
"This is a text in".fg(Color::Yellow),
"paragraph".modifier(Modifier::BOLD).fg(Color::Cyan),
"and it adds".to_span(),
"separator".modifier(Modifier::ITALIC),
);
// Add more text later if needed
p.push("between each span");
// Print the Paragraph as a string
println!("{p}");
// Or you can render it using `Term` (or manually using `Buffer`)
let mut term = Term::default();
term.render(p)?;Implementations
Sourceimpl Paragraph
impl Paragraph
Sourcepub fn new(children: Vec<Box<dyn Text>>) -> Self
pub fn new(children: Vec<Box<dyn Text>>) -> Self
Creates a new Paragraph with the given child elements.
Sourcepub fn separator(self, sep: &str) -> Self
pub fn separator(self, sep: &str) -> Self
Sets the separator used between child elements when rendering the
Paragraph.
Sourcepub fn wrap(self, wrap: Wrap) -> Self
pub fn wrap(self, wrap: Wrap) -> Self
Sets text wrapping style of the Paragraph.
Default value is Wrap::Word.